#
# spec file for package python-pyroma
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
%define skip_python2 1
Name:           python-pyroma
Version:        3.1
Release:        1.11
Summary:        Program to test a Python project's adherence to packaging guidelines
License:        MIT
Group:          Development/Languages/Python
URL:            https://github.com/regebro/pyroma
Source:         https://files.pythonhosted.org/packages/source/p/pyroma/pyroma-%{version}.tar.gz
BuildRequires:  %{python_module Pygments}
BuildRequires:  %{python_module docutils}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-Pygments
Requires:       python-docutils
Requires:       python-setuptools
Requires(post): update-alternatives
Requires(postun):update-alternatives
BuildArch:      noarch
%python_subpackages

%description
Pyroma is a package that gives a rating of how well a Python project
complies with the best practices of the Python packaging ecosystem,
primarily PyPI, pip, Distribute, etc., as well as a list of issues
that could be improved.

It's written so that there are a library with methods to call from Python, as
well as a script, also called pyroma.

%prep
%setup -q -n pyroma-%{version}

%build
export LANG=en_US.UTF-8
%python_build

%install
export LANG=en_US.UTF-8
%python_install
%python_clone -a %{buildroot}%{_bindir}/pyroma
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
export LANG=en_US.UTF-8
%pyunittest discover -v

%post
%python_install_alternative pyroma

%postun
%python_uninstall_alternative pyroma

%files %{python_files}
%license LICENSE.txt
%doc README.rst HISTORY.txt
%python_alternative %{_bindir}/pyroma
%{python_sitelib}/*

%changelog
* Fri May 28 2021 pgajdos@suse.com
- version update to 3.1
  - Added correct detection of setup.py encoding
  - Code cleanup [CAM Gerlach]
  - Drop support for Python 2 [Florian Bruhin]
  - Add back official support for Python 3.6, I didn't realize it was still officially supported
  - Update to the current list of Trove classifiers.
  - Officially support Python 3.8 and 3.9
  - Drop official support for Python 3.5 and 3.6 (still works though).
- %%check: use %%pytestunit rpm macro
* Wed May 20 2020 Petr Gajdos <pgajdos@suse.com>
- %%python3_only -> %%python_alternative
* Fri Mar 20 2020 Marketa Calabkova <mcalabkova@suse.com>
- Update to 2.6
  * Ran flake8 and black on the code, better formatting for
    classifiers.py generation.
  * Support for PEP 517, setup.cfg-only packages. [Max Tyulin]
  * Adds support for Markdown long_descriptions, if you set
    long_description_content_type to 'text/markdown'
  * Installs Pygments to avoid an error message of you have
    syntax highlighted code in the long_description.
* Mon Jun  3 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 2.5:
  - Fixed #35: Correctly restore ``sys.argv``.  [maurits]
  - Added back the BusFactor test, the XMLRPC API supports it.
  - #26: Adding a test to check for a development status classifier.
  - #21: Accept the new project_urls distribution data.
  - Now verifies that classifiers are valid, and that the license field
    and license classifiers match.
  - The rating now again reflects if the long_description isn't valid ReST.
  - #38: Recommendations for the License field has changed.
* Tue Feb 12 2019 Jan Engelhardt <jengelh@inai.de>
- Trim rhetoric storytelling from descriptions.
* Tue Feb 12 2019 John Vandenberg <jayvdb@gmail.com>
- Update to v2.4
  - Get rid of the tests that rely on HTML scraping, it's too brittle.
  - Added -n command line option to set the minimum rating needed for pyroma
    to return success, useful in scripts.
- from 2.3.1
  - Fixed installation fails with a non-UTF8 locale under Python 3.
- Remove unnecessary build dependency on python-devel
- Update URL from BitBucket to GitHub
- Use %%license
- Fix %%doc to use README.rst instead of empty README.txt
* Thu Nov 16 2017 toddrme2178@gmail.com
- Initial version for v2.3
